@@ -101,8 +101,7 @@ class plgCoursesForum extends Hubzero_Plugin
 		{
 			if (!in_array($this_area['name'], $areas)) 
 			{
-				//return $arr;
-				$return = 'metadata';
+				return $arr;
 			}
 		}
 
@@ -182,7 +181,6 @@ class plgCoursesForum extends Hubzero_Plugin
 						$cat->state = 1;
 						$cat->scope = 'course';
 						$cat->scope_id = $this->offering->get('id');
-						$cat->object_id = $unit->get('id');
 						if ($cat->check())
 						{
 							$cat->store();
@@ -259,11 +257,6 @@ class plgCoursesForum extends Hubzero_Plugin
 				break;
 			}
 
-			if (JRequest::getVar('file', ''))
-			{
-				$action = 'download';
-			}
-
 			$action = JRequest::getVar('action', $action, 'post');
 
 			//push the stylesheet to the view
@@ -271,12 +264,6 @@ class plgCoursesForum extends Hubzero_Plugin
 			Hubzero_Document::addPluginStylesheet('courses', $this->_name);
 			Hubzero_Document::addPluginScript('courses', $this->_name);
 
-			$pathway =& JFactory::getApplication()->getPathway();
-			$pathway->addItem(
-				JText::_('PLG_COURSES_' . strtoupper($this->_name)), 
-				'index.php?option=' . $this->option . '&gid=' . $this->course->get('alias') . '&offering=' . $this->offering->get('alias') . '&active=' . $this->_name
-			);
-
 			switch ($action)
 			{
 				case 'sections':       $arr['html'] .= $this->sections();       break;
@@ -325,7 +312,7 @@ class plgCoursesForum extends Hubzero_Plugin
 	{
 		ximport('Hubzero_Document');
 		Hubzero_Document::addPluginStylesheet('courses', $this->_name);
-		Hubzero_Document::addPluginScript('courses', $this->_name, 'forum.lecture');
+		Hubzero_Document::addPluginScript('courses', $this->_name);
 
 		$database = JFactory::getDBO();
 		$this->juser = JFactory::getUser();
@@ -358,11 +345,9 @@ class plgCoursesForum extends Hubzero_Plugin
 		$view->notifications = $this->getPluginMessage();
 		$view->config = $this->params;
 
-		$jconfig = JFactory::getConfig();
-
 		// Incoming
 		$view->filters = array();
-		$view->filters['limit']    = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
+		$view->filters['limit']    = JRequest::getInt('limit', 25);
 		$view->filters['start']    = JRequest::getInt('limitstart', 0);
 		$view->filters['section']  = JRequest::getVar('section', '');
 		$view->filters['category'] = JRequest::getVar('category', '');
@@ -371,9 +356,6 @@ class plgCoursesForum extends Hubzero_Plugin
 		$view->filters['scope']    = 'course';
 		$view->filters['scope_id'] = $course->offering()->get('id');
 		$view->filters['sticky'] = false;
-		$view->filters['start_id'] = JRequest::getInt('start_id', 0);
-		$view->no_html = JRequest::getInt('no_html', 0);
-
 		$sort = JRequest::getVar('sort', 'newest');
 		switch ($sort)
 		{
@@ -409,7 +391,7 @@ class plgCoursesForum extends Hubzero_Plugin
 
 			$section = new ForumSection($database);
 			//if (!$section->loadByObject($course->offering()->get('id'), $this->offering->get('id'), 'course'))
-			if (!$section->loadByAlias($course->offering()->get('alias'), $view->filters['scope_id'], $view->filters['scope']))
+			if (!$section->loadByAlias($course->offering()->get('alias'), $course->offering()->get('id'), 'course'))
 			{
 				// Create a default section
 				$section->title    = $course->offering()->get('title');
@@ -434,7 +416,6 @@ class plgCoursesForum extends Hubzero_Plugin
 				$category->state       = 1;
 				$category->scope       = 'course';
 				$category->scope_id    = $course->offering()->get('id');
-				$category->object_id   = $lecture->get('unit_id');
 				if ($category->check())
 				{
 					$category->store();
@@ -449,298 +430,79 @@ class plgCoursesForum extends Hubzero_Plugin
 		}
 		//$view->filters['parent'] = $view->post->get('id');
 
+		// Get reply count
+		$view->total = $view->post->getCount($view->filters);
+
+		// Get replies
+		$rows = $view->post->getRecords($view->filters);
+
+		$children = array(
+			0 => array()
+		);
+
+		$levellimit = ($view->filters['limit'] == 0) ? 500 : $view->filters['limit'];
+
+		// first pass - collect children
+		foreach ($rows as $v)
+		{
+			/*$children[0][] = $v;
+			$children[$v->get('id')] = $v->children();*/
+			
+			//$v->set('name', '');
+			$pt      = $v->parent;
+			$list    = @$children[$pt] ? $children[$pt] : array();
+			array_push($list, $v);
+			$children[$pt] = $list;
+		}
+		// second pass - get an indent list of the items
+		//$list = $this->treeRecurse(0, '', array(), $children, max(0, $levellimit-1));
+		if (isset($children[$view->post->get('id')]))
+		{
+			$view->rows = $this->treeRecurse($children[$view->post->get('id')], $children);
+		}
+
+//$view->rows = null;
+		//$view->total = count($list);
+
+		//$view->rows = array_slice($list, $view->filters['start'], $view->filters['limit']);
+		/*if ($view->rows && count($view->rows) > 0)
+		{
+			$filters = $view->filters['parent'];
+			$filters['limit'] = 0;
+			foreach ($view->rows as $k => $row)
+			{
+				$filters['parent'] = $row->id;
+				$view->rows[$k]->replies = $this->getRecords($filters);
+				if ($view->rows[$k]->replies && count($view->rows[$k]->replies) > 0)
+				{
+					foreach ($view->rows[$k]->replies as $j => $reply)
+					{
+						$filters['parent'] = $reply->id;
+						$view->rows[$k]->replies[$j]->replies = $this->getRecords($filters);
+					}
+				}
+			}
+		}*/
+		//$view->filters['parent'] = $view->post->get('id');
+
+		// Record the hit
+		//$view->participants = $view->post->getParticipants($view->filters);
+
 		// Get attachments
 		$view->attach = new ForumAttachment($database);
 		$view->attachments = $view->attach->getAttachments($view->post->id);
 
-		if ($view->no_html == 1)
-		{
-			$view->filters['start_at'] = JRequest::getVar('start_at', '');
-			if ($view->filters['start_id'])
-			{
-				$view->filters['limit'] = 0;
-				$view->filters['start'] = 0;
-			}
+		// Get tags on this article
+		//$view->tModel = new ForumTags($this->database);
+		//$view->tags = $view->tModel->get_tag_cloud(0, 0, $view->post->id);
 
-			if (JRequest::getInt('count', 0))
-			{
-				$data = new stdClass();
-				$data->code = 0;
-				if ($this->getError())
-				{
-					$data->code = 1;
-					//$data->errors = $this->getErrors();
-				}
-				$data->count = $view->post->count($view->filters);
-				//$data->response = $rows;
-
-				ob_clean();
-				header('Content-type: text/plain');
-				echo json_encode($data);
-				exit();
-			}
-			$rows = $view->post->find($view->filters);
-			if ($rows)
-			{
-				if ($view->filters['start_id'])
-				{
-					$view->filters['limit']    = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
-
-					$children = array(
-						0 => array()
-					);
-
-					$levellimit = ($view->filters['limit'] == 0) ? 500 : $view->filters['limit'];
-
-					foreach ($rows as $v)
-					{
-						//$children[0][] = $v;
-						//$children[$v->id] = $v->children();
-
-						//$v->set('name', '');
-						$pt      = $v->parent;
-						$list    = @$children[$pt] ? $children[$pt] : array();
-						array_push($list, $v);
-						$children[$pt] = $list;
-					}
-
-					$list = $this->_treeRecurse($view->post->get('id'), '', array(), $children, max(0, $levellimit-1));
-
-					$inc = false;
-					$newlist = array();
-					foreach ($list as $l)
-					{
-						
-						if ($l->id == $view->filters['start_id']) 
-						{
-							$inc = true;
-						}
-						else
-						{
-							if ($inc)
-							{
-								$newlist[] = $l;
-							}
-						}
-					}
-
-					$rows = array_slice($newlist, $view->filters['start'], $view->filters['limit']);
-				}
-				
-				
-				ximport('Hubzero_User_Profile');
-				ximport('Hubzero_Wiki_Parser');
-
-				$wikiconfig = array(
-					'option'   => $view->option,
-					'scope'    => 'forum',
-					'pagename' => 'forum',
-					'pageid'   => $view->post->id,
-					'filepath' => '',
-					'domain'   => $view->post->id
-				);
-
-				$p =& Hubzero_Wiki_Parser::getInstance();
-
-				//ximport('Hubzero_User_Profile_Helper');
-
-				//$config =& JComponentHelper::getParams('com_members');
-				//$dfthumb = DS . trim($config->get('defaultpic', '/components/com_members/assets/img/profile.gif'), DS);
-				//$dfthumb = Hubzero_User_Profile_Helper::thumbit($dfthumb);
-
-				foreach ($rows as $key => $row)
-				{
-					/*if ($row->anonymous)
-					{
-						$rows[$key]->picture = $dfthumb;
-						$rows[$key]->name = JText::_('PLG_COURSES_FORUM_ANONYMOUS');
-					}
-					else
-					{
-						$thumb .= DS . trim($config->get('webpath', '/site/members'), DS);
-						$thumb .= DS . Hubzero_User_Profile_Helper::niceidformat($row->created_by);
-
-						//$thumbAlt = $thumb . DS . ltrim($row->picture, DS);
-						$thumbAlt = $thumb . DS . 'thumb.png';
-
-						$thumb .= DS . ltrim($row->picture, DS);
-						$thumb = Hubzero_User_Profile_Helper::thumbit($thumb);
-
-						if ($thumbAlt && file_exists(JPATH_ROOT . $thumbAlt)) 
-						{
-							$rows[$key]->picture = $thumbAlt;
-						} 
-						else if ($thumb && file_exists(JPATH_ROOT . $thumb)) 
-						{
-							$rows[$key]->picture = $thumb;
-						}
-						else
-						{
-							$rows[$key]->picture = $dfthumb;
-						}
-					}
-					if ($row->reports)
-					{
-						$rows[$key]->comment = '<p class="warning">' . JText::_('This comment has been reported as abusive and/or containing inappropriate content.') . '</p>';
-					}
-					else
-					{
-						$rows[$key]->comment = $p->parse(stripslashes($row->comment), $wikiconfig, false);
-						$rows[$key]->comment .= $view->attach->getAttachment(
-							$row->id, 
-							'index.php?option=' . $view->option . '&gid=' . $view->course->get('alias') . '&offering=' . $view->course->offering()->get('alias') . '&active=forum&unit=' . $view->unit->get('alias') . '&b=' . $row->category_id . '&c=' . $row->id . '&file=', 
-							$view->config
-						);
-					}*/
-					$rows[$key]->replies = null;
-	
-					/*ximport('Hubzero_User_Profile');
-					ximport('Hubzero_Wiki_Parser');
-
-					$wikiconfig = array(
-						'option'   => $view->option,
-						'scope'    => 'forum',
-						'pagename' => 'forum',
-						'pageid'   => $view->post->id,
-						'filepath' => '',
-						'domain'   => $view->post->id
-					);
-
-					$p =& Hubzero_Wiki_Parser::getInstance();*/
-
-					$cview = new Hubzero_Plugin_View(
-						array(
-							'folder'  => 'courses',
-							'element' => 'forum',
-							'name'    => 'threads',
-							'layout'  => 'comment'
-						)
-					);
-					$cview->option     = $this->option;
-					$cview->comment    = $row;
-					$cview->post       = $view->post;
-					$cview->unit       = $view->unit->get('alias');
-					$cview->lecture    = $view->lecture->get('alias');
-					$cview->config     = $view->config;
-					$cview->depth      = 0;
-					$cview->cls        = 'odd';
-					$cview->base       = 'index.php?option=' . $view->option . '&gid=' . $view->course->get('alias') . '&offering=' . $view->course->offering()->get('alias') . '&active=outline';
-					$cview->parser     = $p;
-					$cview->wikiconfig = $wikiconfig;
-					$cview->attach     = $view->attach;
-					$cview->course     = $view->course;
-					
-					$rows[$key]->html = $cview->loadTemplate();
-				}
-			}
-		}
-		else
-		{
-			// Get reply count
-			$view->total = $view->post->getCount($view->filters);
-
-//$view->filters['parent'] = $view->post->get('id');
-
-			// Get replies
-			//$rows = $view->post->getRecords($view->filters);
-			$rows = $view->post->find($view->filters);
-
-			/*$children = array(
-				0 => array()
-			);
-
-			$levellimit = ($view->filters['limit'] == 0) ? 500 : $view->filters['limit'];
-
-			// first pass - collect children
-			$view->last = '0000-00-00 00:00:00';
-			foreach ($rows as $v)
-			{
-				$pt      = $v->parent;
-				$list    = @$children[$pt] ? $children[$pt] : array();
-				array_push($list, $v);
-				$children[$pt] = $list;
-			}
-			// second pass - get an indent list of the items
-			//$list = $this->treeRecurse(0, '', array(), $children, max(0, $levellimit-1));
-			if (isset($children[$view->post->get('id')]))
-			{
-				$view->rows = $this->treeRecurse($children[$view->post->get('id')], $children);
-			}*/
-			//$rows = $view->post->getRecords($view->filters);
-
-			$children = array(
-				0 => array()
-			);
-
-			$levellimit = ($view->filters['limit'] == 0) ? 500 : $view->filters['limit'];
-
-			foreach ($rows as $v)
-			{
-				//$children[0][] = $v;
-				//$children[$v->id] = $v->children();
-
-				//$v->set('name', '');
-				$pt      = $v->parent;
-				$list    = @$children[$pt] ? $children[$pt] : array();
-				array_push($list, $v);
-				$children[$pt] = $list;
-			}
-
-			$list = $this->_treeRecurse($view->post->get('id'), '', array(), $children, max(0, $levellimit-1));
-
-			$rows = array_slice($list, $view->filters['start'], $view->filters['limit']);
-
-
-
-			$view->last = '0000-00-00 00:00:00';
-			$children = array(
-				0 => array()
-			);
-			foreach ($rows as $v)
-			{
-				if ($v->created > $view->last)
-				{
-					$view->last = $v->created;
-				}
-				$v->treename = '';
-
-				$pt      = $v->parent;
-				$list    = @$children[$pt] ? $children[$pt] : array();
-				array_push($list, $v);
-				$children[$pt] = $list;
-				$view->last_id = $v->id;
-			}
-			
-			if (isset($children[$view->post->get('id')]))
-			{
-				$view->rows = $this->treeRecurse($children[$view->post->get('id')], $children);
-			}
-			else
-			{
-				$view->rows = array();
-			}
-
-			/*if ($rows)
-			{
-				foreach ($rows as $k => $v)
-				{
-					if ($v->created > $view->last)
-					{
-						$view->last = $v->created;
-					}
-					$rows[$k]->replies = $this->threadRecurse($v->id, $view->post, 3);
-				}
-			}*/
-			//$view->rows = $rows;
-
-			// Initiate paging
-			jimport('joomla.html.pagination');
-			$view->pageNav = new JPagination(
-				($view->total - 1), // subtract one for the thread starter
-				$view->filters['start'], 
-				$view->filters['limit']
-			);
-		}
+		// Initiate paging
+		jimport('joomla.html.pagination');
+		$view->pageNav = new JPagination(
+			($view->total - 1), // subtract one for the thread starter
+			$view->filters['start'], 
+			$view->filters['limit']
+		);
 
 		// Set any errors
 		if ($this->getError()) 
@@ -751,28 +513,6 @@ class plgCoursesForum extends Hubzero_Plugin
 			}
 		}
 
-		if ($view->no_html == 1)
-		{
-			$data = new stdClass();
-			$data->code = 0;
-			if ($this->getError())
-			{
-				$data->code = 1;
-				//$data->errors = $this->getErrors();
-			}
-			$data->response = $rows;
-
-			ob_clean();
-			//echo $view->loadTemplate();
-			//echo '<textarea id="response">';
-			//header('Content-type: application/json');
-			header('Content-type: text/plain');
-			echo json_encode($data);
-			//echo '</textarea>';
-			//echo '<script type="text/javascript">window.top.window.HUB.Plugins.CoursesForum.updateComments(document.getElementById("response"));</script>';
-			exit();
-		}
-
 		return $view->loadTemplate();
 	}
 
@@ -803,20 +543,6 @@ class plgCoursesForum extends Hubzero_Plugin
 		return $children;
 	}
 
-	public function threadRecurse($parent, $obj, $limit, $maxlevel=9999, $level=0)
-	{
-		$children = null;
-		if ($level <= $maxlevel)
-		{
-			$children = $obj->find(array('parent' => $parent, 'limit' => $limit, 'start' => 0, 'state' => 1, 'sort' => 'created', 'sort_Dir' => 'DESC'));
-			foreach ($children as $v => $child)
-			{
-				$children[$v]->replies = $this->threadRecurse($child->id, $obj, $limit, $maxlevel, $level+1);
-			}
-		}
-		return $children;
-	}
-
 	/**
 	 * Set redirect and message
 	 * 
@@ -1201,12 +927,10 @@ class plgCoursesForum extends Hubzero_Plugin
 			)
 		);
 
-		$jconfig = JFactory::getConfig();
-
 		// Incoming
 		$view->filters = array();
 		$view->filters['authorized'] = 1;
-		$view->filters['limit']    = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
+		$view->filters['limit']    = JRequest::getInt('limit', 25);
 		$view->filters['start']    = JRequest::getInt('limitstart', 0);
 		$view->filters['section']  = JRequest::getVar('section', '');
 		$view->filters['category'] = JRequest::getVar('category', '');
@@ -1289,12 +1013,10 @@ class plgCoursesForum extends Hubzero_Plugin
 			)
 		);
 
-		$jconfig = JFactory::getConfig();
-
 		// Incoming
 		$this->view->filters = array();
 		$this->view->filters['authorized'] = 1;
-		$this->view->filters['limit']    = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
+		$this->view->filters['limit']    = JRequest::getInt('limit', 25);
 		$this->view->filters['start']    = JRequest::getInt('limitstart', 0);
 		$this->view->filters['search']   = JRequest::getVar('q', '');
 		$this->view->filters['scope']    = 'course';
@@ -1609,19 +1331,16 @@ class plgCoursesForum extends Hubzero_Plugin
 			)
 		);
 
-		$jconfig = JFactory::getConfig();
-
 		// Incoming
 		$view->filters = array();
-		$view->filters['limit'] = null;
+		$view->filters['limit']    = JRequest::getInt('limit', 25);
+		$view->filters['start']    = JRequest::getInt('limitstart', 0);
 		$view->filters['section']  = $this->offering->get('alias'); //JRequest::getVar('section', '');
 		$view->filters['category'] = JRequest::getVar('category', '');
 		//$view->filters['parent']   = JRequest::getInt('thread', 0);
 		$view->filters['state']    = 1;
 		$view->filters['scope']    = 'course';
 		$view->filters['scope_id'] = $this->offering->get('id');
-		$view->filters['sort_Dir'] = 'ASC';
-		$view->filters['sort'] = 'c.created';
 
 		$thread   = JRequest::getInt('thread', 0);
 
@@ -1661,35 +1380,12 @@ class plgCoursesForum extends Hubzero_Plugin
 		// Get reply count
 		$view->total = $view->post->getCount($view->filters);
 
-		//$view->filters['parent']   = $view->post->id;
+		// Get replies
+		//$view->rows = $view->post->getRecords($view->filters);
 		// Get replies
 		//$view->filters['parent'] = 0;
 		$rows = $view->post->getRecords($view->filters);
 
-		$view->filters['limit']    = JRequest::getInt('limit', $jconfig->getValue('config.list_limit'));
-		$view->filters['start']    = JRequest::getInt('limitstart', 0);
-
-		$children = array(
-			0 => array()
-		);
-
-		$levellimit = ($view->filters['limit'] == 0) ? 500 : $view->filters['limit'];
-		
-		foreach ($rows as $v)
-		{
-			//$children[0][] = $v;
-			//$children[$v->id] = $v->children();
-			
-			//$v->set('name', '');
-			$pt      = $v->parent;
-			$list    = @$children[$pt] ? $children[$pt] : array();
-			array_push($list, $v);
-			$children[$pt] = $list;
-		}
-		// Get replies
-		//$view->filters['parent'] = 0;
-		/*$rows = $view->post->getRecords($view->filters);
-
 		$children = array(
 			0 => array()
 		);
@@ -1699,32 +1395,38 @@ class plgCoursesForum extends Hubzero_Plugin
 		// first pass - collect children
 		foreach ($rows as $v)
 		{
+			/*$children[0][] = $v;
+			$children[$v->get('id')] = $v->children();*/
+			
+			//$v->set('name', '');
 			$pt      = $v->parent;
 			$list    = @$children[$pt] ? $children[$pt] : array();
 			array_push($list, $v);
 			$children[$pt] = $list;
 		}
-
+		
 		// second pass - get an indent list of the items
+		//$list = $this->treeRecurse(0, '', array(), $children, max(0, $levellimit-1));
 		$view->rows = array();
 		if (isset($children[$view->post->get('id')]))
 		{
 			$view->rows = $this->treeRecurse($children[$view->post->get('id')], $children);
 		}
-
+		/*if (!$view->rows)
+		{
+			$view->rows = array();
+		}*/
 		if (isset($children[0]) && !$children[0][0]->object_id)
 		{
 			array_unshift($view->rows, $children[0][0]);
-		}*/
-		$list = $this->_treeRecurse(0, '', array(), $children, max(0, $levellimit-1));
-
-		$view->rows = array_slice($list, $view->filters['start'], $view->filters['limit']);
+		}
+		
 
 		$view->filters['parent']   = $view->post->id;
 
 		// Record the hit
 		$view->participants = $view->post->getParticipants($view->filters);
-
+		
 		// Get attachments
 		$view->attach = new ForumAttachment($this->database);
 		$view->attachments = $view->attach->getAttachments($view->post->id);
@@ -1763,57 +1465,6 @@ class plgCoursesForum extends Hubzero_Plugin
 		return $view->loadTemplate();
 	}
 
-	/**
-	 * Recursive function to build tree
-	 * 
-	 * @param      integer $id       Parent ID
-	 * @param      string  $indent   Indent text
-	 * @param      array   $list     List of records
-	 * @param      array   $children Container for parent/children mapping
-	 * @param      integer $maxlevel Maximum levels to descend
-	 * @param      integer $level    Indention level
-	 * @param      integer $type     Indention type
-	 * @return     void
-	 */
-	public function _treeRecurse($id, $indent, $list, $children, $maxlevel=9999, $level=0, $type=1)
-	{
-		if (@$children[$id] && $level <= $maxlevel)
-		{
-			foreach ($children[$id] as $v)
-			{
-				$id = $v->id;
-
-				//if ($type) 
-				//{
-					$pre    = ' treenode';
-					$spacer = ' indent' . $level;
-				/*} 
-				else 
-				{
-					$pre    = '- ';
-					$spacer = '&nbsp;&nbsp;';
-				}*/
-
-				if ($v->parent == 0) 
-				{
-					$txt = '';
-				} 
-				else 
-				{
-					$txt = $pre;
-				}
-				$pt = $v->parent;
-
-				$list[$id] = $v;
-				$list[$id]->treename = "$indent$txt";
-				$list[$id]->children = count(@$children[$id]);
-
-				$list = $this->_treeRecurse($id, $indent . $spacer, $list, $children, $maxlevel, $level+1, $type);
-			}
-		}
-		return $list;
-	}
-
 	/**
 	 * Show a form for editing a post
 	 * 
@@ -1946,8 +1597,6 @@ class plgCoursesForum extends Hubzero_Plugin
 		// Incoming
 		$section = JRequest::getVar('section', '');
 
-		$no_html = JRequest::getInt('no_html', 0);
-
 		$fields = JRequest::getVar('fields', array(), 'post');
 		$fields = array_map('trim', $fields);
 
@@ -1979,12 +1628,6 @@ class plgCoursesForum extends Hubzero_Plugin
 		$model = new ForumPost($this->database);
 		if (!$model->bind($fields)) 
 		{
-			/*if ($no_html)
-			{
-				ob_clean();
-				echo $model->getError();
-				exit;
-			}*/
 			$this->addPluginMessage($model->getError(), 'error');
 			return $this->editthread($model);
 		}
@@ -1992,12 +1635,6 @@ class plgCoursesForum extends Hubzero_Plugin
 		// Check content
 		if (!$model->check()) 
 		{
-			/*if ($no_html)
-			{
-				ob_clean();
-				echo $model->getError();
-				exit;
-			}*/
 			$this->addPluginMessage($model->getError(), 'error');
 			return $this->editthread($model);
 		}
@@ -2005,12 +1642,6 @@ class plgCoursesForum extends Hubzero_Plugin
 		// Store new content
 		if (!$model->store()) 
 		{
-			/*if ($no_html)
-			{
-				ob_clean();
-				echo $model->getError();
-				exit;
-			}*/
 			$this->addPluginMessage($model->getError(), 'error');
 			return $this->editthread($model);
 		}
@@ -2099,7 +1730,7 @@ class plgCoursesForum extends Hubzero_Plugin
 			$forum_message = $p->parse("\n".stripslashes($forum_message), $wikiconfig);		
 			*/
 
-			ximport('Hubzero_EmailToken');
+			ximport('Hubzero_Emailtoken');
 			// Figure out who should be notified about this comment (all course members for now)
 			$userIDsToEmail = array();
 
@@ -2113,7 +1744,7 @@ class plgCoursesForum extends Hubzero_Plugin
 					include_once(JPATH_ROOT . DS . 'plugins' . DS . 'courses' . DS . 'memberoptions' . DS . 'memberoption.class.php');
 
 					// Find the user's course settings, do they want to get email (0 or 1)?
-					$courseMemberOption = new Courses_MemberOption($this->database);
+					$courseMemberOption = new courses_MemberOption($this->database);
 					$courseMemberOption->loadRecord(
 						$this->course->get('id'), 
 						$user->id, 
@@ -2139,7 +1770,7 @@ class plgCoursesForum extends Hubzero_Plugin
 			// Email each course member separately, each needs a user specific token
 			foreach ($userIDsToEmail as $userID)
 			{
-				ximport('Hubzero_EmailToken');
+				ximport('Hubzero_Emailtoken');
 				$encryptor = new Hubzero_Email_Token();
 				$jconfig =& JFactory::getConfig();
 
@@ -2161,12 +1792,6 @@ class plgCoursesForum extends Hubzero_Plugin
 			}
 		}
 
-		if ($no_html == 1)
-		{
-			$unit = $this->course->offering()->unit($category->alias);
-			return $this->onCourseAfterLecture($this->course, $unit, $unit->assetgroup($model->object_id));
-		}
-
 		$rtrn = base64_decode(JRequest::getVar('return', '', 'post'));
 		if (!$rtrn)
 		{
@@ -2353,16 +1978,16 @@ class plgCoursesForum extends Hubzero_Plugin
 	public function download()
 	{
 		// Incoming
-		//$section = JRequest::getVar('section', '');
-		$category = JRequest::getVar('unit', '');
-		$thread = JRequest::getInt('group', 0);
-		$post = JRequest::getInt('asset', 0);
+		$section = JRequest::getVar('section', '');
+		$category = JRequest::getVar('category', '');
+		$thread = JRequest::getInt('thread', 0);
+		$post = JRequest::getInt('post', 0);
 		$file = JRequest::getVar('file', '');
 
 		// Check logged in status
 		if ($this->juser->get('guest')) 
 		{
-			$return = JRoute::_('index.php?option=' . $this->option . '&gid=' . $this->course->get('alias') . '&controller=offering&offering=' . $this->offering->get('alias') . '&active=forum&unit=' . $category . '&b=' . $thread . '&c=' . $post . '&file=' . $file);
+			$return = JRoute::_('index.php?option=' . $this->option . '&gid=' . $this->course->get('alias') . '&offering=' . $this->offering->get('alias') . '&active=forum&unit=' . $section . '&b=' . $category . '&c=' . $thread . '/' . $post . '/' . $file);
 			$this->setRedirect(
 				JRoute::_('index.php?option=com_login&return=' . base64_encode($return))
 			);
@@ -2408,8 +2033,7 @@ class plgCoursesForum extends Hubzero_Plugin
 		$this->_authorize('thread', $this->model->id);
 
 		// Ensure the user is authorized to view this file
-		//if (!$this->params->get('access-view-thread')) 
-		if (!$this->course->access('view'))
+		if (!$this->params->get('access-view-thread')) 
 		{
 			JError::raiseError(403, JText::_('PLG_COURSES_FORUM_NOT_AUTH_FILE'));
 			return;
